summaryrefslogtreecommitdiffstats
path: root/chrome/browser/autofill/autofill_xml_parser_unittest.cc
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-01 22:14:18 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-01 22:14:18 +0000
commit7127ca8f76464fbc40f578034254b0ce778a6dae (patch)
tree9bb797184c3a87445b34728c2dddf088fc461d03 /chrome/browser/autofill/autofill_xml_parser_unittest.cc
parent77c93df6ab9299e0f28349966caf391f1d1d35e5 (diff)
downloadchromium_src-7127ca8f76464fbc40f578034254b0ce778a6dae.zip
chromium_src-7127ca8f76464fbc40f578034254b0ce778a6dae.tar.gz
chromium_src-7127ca8f76464fbc40f578034254b0ce778a6dae.tar.bz2
autofill: Rename AutoFillFieldType to AutofillFieldType.
BUG=72758 TEST=compiled locally and trybots Review URL: http://codereview.chromium.org/6592067 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@76442 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/autofill/autofill_xml_parser_unittest.cc')
-rw-r--r--chrome/browser/autofill/autofill_xml_parser_unittest.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/chrome/browser/autofill/autofill_xml_parser_unittest.cc b/chrome/browser/autofill/autofill_xml_parser_unittest.cc
index 11d1ee6..5f5146c 100644
--- a/chrome/browser/autofill/autofill_xml_parser_unittest.cc
+++ b/chrome/browser/autofill/autofill_xml_parser_unittest.cc
@@ -21,8 +21,8 @@ TEST(AutoFillQueryXmlParserTest, BasicQuery) {
"<field autofilltype=\"2\" />"
"</autofillqueryresponse>";
- // Create a vector of AutoFillFieldTypes, to assign the parsed field types to.
- std::vector<AutoFillFieldType> field_types;
+ // Create a vector of AutofillFieldTypes, to assign the parsed field types to.
+ std::vector<AutofillFieldType> field_types;
UploadRequired upload_required = USE_UPLOAD_RATES;
std::string experiment_id;
@@ -43,7 +43,7 @@ TEST(AutoFillQueryXmlParserTest, BasicQuery) {
// Test parsing the upload required attribute.
TEST(AutoFillQueryXmlParserTest, TestUploadRequired) {
- std::vector<AutoFillFieldType> field_types;
+ std::vector<AutofillFieldType> field_types;
UploadRequired upload_required = USE_UPLOAD_RATES;
std::string experiment_id;
@@ -95,7 +95,7 @@ TEST(AutoFillQueryXmlParserTest, TestUploadRequired) {
// Test parsing the experiment id attribute
TEST(AutoFillQueryXmlParserTest, ParseExperimentId) {
- std::vector<AutoFillFieldType> field_types;
+ std::vector<AutofillFieldType> field_types;
UploadRequired upload_required = USE_UPLOAD_RATES;
std::string experiment_id;
@@ -155,7 +155,7 @@ TEST(AutoFillQueryXmlParserTest, ParseExperimentId) {
// Test badly formed XML queries.
TEST(AutoFillQueryXmlParserTest, ParseErrors) {
- std::vector<AutoFillFieldType> field_types;
+ std::vector<AutofillFieldType> field_types;
UploadRequired upload_required = USE_UPLOAD_RATES;
std::string experiment_id;